pub struct Span {
pub lo: BytePos,
pub hi: BytePos,
}Expand description
A span of source code, represented as a half-open byte range [lo, hi).
Fields
lo: BytePosThe start of the span (inclusive).
hi: BytePosThe end of the span (exclusive).
Implementations
Sourceimpl Span
impl Span
Sourcepub const fn to(self, other: Self) -> Self
pub const fn to(self, other: Self) -> Self
Create a span that covers from the start of self to the end of other.
Sourcepub const fn shrink_to_lo(self) -> Self
pub const fn shrink_to_lo(self) -> Self
Shrink the span to a single point at the start.
Sourcepub const fn shrink_to_hi(self) -> Self
pub const fn shrink_to_hi(self) -> Self
Shrink the span to a single point at the end.